CodegenSettings

Struct CodegenSettings 

pub struct CodegenSettings {
    pub optionable_crate_name: Path,
    pub ty_prefix: Option<Path>,
    pub input_crate_replacement: Option<Ident>,
}
Settings that are only available to be set via the rust function signature of derive_optionable but not via the derive macro (as they are not useful in that context and would lead to an increased but not useful API surface of the derive macro helpers).

Fields

optionable_crate_name: Path

Name of the optionable crate to use for the generated code including potentially leading ::. Useful to set when generating code for the optionable crate itself where one needs to refer to it as crate.

ty_prefix: Option<Path>

Path prefix to prepend to the respective type. E.g. with a ty_prefix of ::mycrate the output would be (simplified) impl Optionable for ::mycrate::mytype.

input_crate_replacement: Option<Ident>

Replacement for the keyword crate in the input type/enum definition or references. Useful when generating code for the optionable crate as pre-existing crate references need to be replaced with the concret crate name.