FieldAttributeToCopy

Struct FieldAttributeToCopy 

pub struct FieldAttributeToCopy {
    pub attr: Path,
    pub key: Option<Path>,
}
Forwards the specified attr to the definition of the optioned type. If sub_names is set it filters the configuration of the forwarded attribure for the specified configuration names. E.g. attr=serde,sub_names=rename will only forward the renamesub-attribute of serde.

Fields

attr: Pathkey: Option<Path>