pub struct FieldAttributeToCopy {
pub attr: Path,
pub key: Option<Path>,
}Expand description
Forwards the specified attr to the definition of the optioned type.
If sub_names is set it filters the configuration of the forwarded attribure for the specified configuration names.
E.g. attr=serde,sub_names=rename will only forward the renamesub-attribute of serde.
Fields
attr: Pathkey: Option<Path>Trait Implementations
Sourceimpl FromMeta for FieldAttributeToCopy
impl FromMeta for FieldAttributeToCopy
Sourcefn from_list(__items: &[NestedMeta]) -> Result<Self>
fn from_list(__items: &[NestedMeta]) -> Result<Self>
Create an instance from a list of nested meta items.
fn from_nested_meta(item: &NestedMeta) -> Result<Self, Error>
Sourcefn from_meta(item: &Meta) -> Result<Self, Error>
fn from_meta(item: &Meta) -> Result<Self, Error>
Create an instance from a
syn::Meta by dispatching to the format-appropriate
trait function. This generally should not be overridden by implementers. Read moreSourcefn from_none() -> Option<Self>
fn from_none() -> Option<Self>
When a field is omitted from a parent meta-item,
from_none is used to attempt
recovery before a missing field error is generated. Read moreSourcefn from_word() -> Result<Self, Error>
fn from_word() -> Result<Self, Error>
Create an instance from the presence of the word in the attribute with no
additional options specified.
Sourcefn from_value(value: &Lit) -> Result<Self, Error>
fn from_value(value: &Lit) -> Result<Self, Error>
Create an instance from a literal value of either
foo = "bar" or foo("bar").
This dispatches to the appropriate method based on the type of literal encountered,
and generally should not be overridden by implementers. Read morefn from_expr(expr: &Expr) -> Result<Self, Error>
Sourcefn from_char(value: char) -> Result<Self, Error>
fn from_char(value: char) -> Result<Self, Error>
Create an instance from a char literal in a value position.